@@ -3,7 +3,7 @@ use v5.10.1;
 use strict;
 use warnings FATAL => 'all';
 
-our $VERSION = "0.09";
+our $VERSION = "0.10";
 
 BEGIN {
     $ENV{TEST_NGINX_BINARY} ||= 'openresty';
@@ -11,13 +11,17 @@ BEGIN {
 
 use Test::Nginx::Socket::Lua -Base;
 
-use Cwd qw(cwd);
+use Cwd qw(cwd abs_path);
+use File::Spec::Functions qw(catfile);
+use File::Slurp qw(read_file);
 
 my $pwd = cwd();
 our $path = $ENV{TEST_NGINX_APICAST_PATH} ||= "$pwd/gateway";
 our $spec = "$pwd/spec";
 our $servroot = $Test::Nginx::Util::ServRoot;
 
+our $Fixtures = abs_path($ENV{TEST_NGINX_FIXTURES} || catfile('t', 'fixtures'));
+
 # src/?/policy.lua allows us to require apicast.policy.apolicy
 $ENV{TEST_NGINX_LUA_PATH} = "$path/src/?.lua;$path/src/?/policy.lua;;";
 $ENV{TEST_NGINX_MANAGEMENT_CONFIG} = "$path/conf.d/management.conf";
@@ -153,6 +157,23 @@ sub Test::Base::Filter::env {
     return Test::Nginx::Util::expand_env_in_config($input);
 }
 
+sub Test::Base::Filter::fixture {
+    my $name = filter_arguments;
+
+    if (! $name) {
+        bail_out("fixture filter needs argument - file to be loaded");
+    };
+
+    my $file = catfile($Fixtures, $name);
+
+    if (! -f $file) {
+        bail_out("$file is not a file - fixture cannot be loaded");
+    }
+    my $contents = read_file($file);
+
+    return $contents;
+}
+
 1;
 __END__
 
