@@ -14,6 +14,15 @@ BEGIN {
 
 our $ApicastBinary = $ENV{TEST_NGINX_APICAST_BINARY} || 'bin/apicast';
 
+our %EnvToNginx = ();
+
+sub env_to_apicast (@) {
+    my %env = (@_);
+
+    # merge two hashes, new %env takes precedence
+    %EnvToNginx = (%EnvToNginx, %env);
+};
+
 add_block_preprocessor(sub {
     my $block = shift;
     my $seq = $block->seq_num;
@@ -118,7 +127,7 @@ my $write_nginx_config = sub {
 
     my ($env, $env_file) = tempfile();
 
-    my $apicast_cmd = "APICAST_CONFIGURATION_LOADER='' $apicast_cli start --test --environment $env_file";
+    my $apicast_cmd = "APICAST_CONFIGURATION_LOADER='test' $apicast_cli start --test --environment $env_file";
 
     if (defined $configuration_file) {
         $apicast_cmd .= " --configuration $configuration_file"
@@ -126,6 +135,13 @@ my $write_nginx_config = sub {
         $configuration_file = "";
     }
 
+    my %env = (%EnvToNginx, $block->env);
+    my @env_list = ();
+
+    for my $key (keys %env) {
+        push @env_list, "$key='$env{$key}'";
+    }
+
     if (defined $environment) {
         print $env $environment;
     } else {
@@ -147,7 +163,7 @@ return {
     },
     env = {
         THREESCALE_CONFIG_FILE = [[$configuration_file]],
-        APICAST_CONFIGURATION_LOADER = 'boot',
+        APICAST_CONFIGURATION_LOADER = 'boot', ${\(join(', ', @env_list))}
     },
     server_name = {
         management = $management_server_name
@@ -187,4 +203,8 @@ BEGIN {
     }
 }
 
+our @EXPORT = qw(
+    env_to_apicast
+);
+
 1;
